@@ -61,7 +61,7 @@ class _BloxrouteMessageFactoryV6(AbstractMessageFactory):
         BloxrouteMessageType.TRANSACTION_CLEANUP: TransactionCleanupMessage
     }
 
-    def __init__(self):
+    def __init__(self) -> None:
         super(_BloxrouteMessageFactoryV6, self).__init__()
         self.message_type_mapping = self._MESSAGE_TYPE_MAPPING
 
@@ -100,7 +100,7 @@ class _BloxrouteMessageFactoryV6(AbstractMessageFactory):
             return BroadcastMessagePreview(is_full_header, Sha256Hash(message_hash), network_num, source_id,
                                            payload_length)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"{self.__class__.__name__}; message_type_mapping: {self.message_type_mapping}"
 
 
