@@ -121,6 +121,11 @@ class NodeModel:
     # this property is ignored for relays
     node_privileges: str = util_constants.DEFAULT_NODE_PRIVILEGES
 
+    # pyre-fixme[8]: Attribute has type `str`; used as `None`.
+    first_seen_time: str = None
+
+    is_docker: bool = False
+
     def __post_init__(self):
         self.sid_expire_time = constants.SID_EXPIRE_TIME_SECONDS
         # TODO: Remove network attribute, not being used
