@@ -13,6 +13,7 @@ from typing import List, Tuple, Generator, Optional, Union, Dict, Set, Any, Iter
 from prometheus_client import Gauge
 
 from bxcommon import constants
+from bxcommon.messages.bloxroute import short_ids_serializer
 from bxcommon.models.quota_type_model import QuotaType
 from bxcommon.models.transaction_info import TransactionSearchResult, TransactionInfo
 from bxcommon.utils import memory_utils, convert
@@ -290,13 +291,21 @@ class TransactionService:
 
         return None
 
-    def get_transactions(self, short_ids: List[int]) -> TransactionSearchResult:
+    def get_transactions(
+        self,
+        serialized_short_ids: Optional[bytearray] = None
+    ) -> TransactionSearchResult:
         """
         Fetches all transaction info for a set of short ids.
         Short ids without a transaction entry will be omitted.
-        :param short_ids: list of short ids
+        Function allows to pass a single short id or serialized list of short ids
+        :param serialized_short_ids: instance of get transactions message
         :return: list of found and missing short ids
         """
+
+        assert serialized_short_ids is not None
+        short_ids = short_ids_serializer.deserialize_short_ids(serialized_short_ids)
+
         found = []
         missing = []
         for short_id in short_ids:
@@ -307,10 +316,10 @@ class TransactionService:
                                                  self._tx_cache_key_to_contents[transaction_cache_key],
                                                  short_id))
                 else:
-                    missing.append(TransactionInfo(self._tx_cache_key_to_hash(transaction_cache_key), None, short_id))
+                    missing.append(short_id)
                     logger.trace("Short id {} was requested but is unknown.", short_id)
             else:
-                missing.append(TransactionInfo(None, None, short_id))
+                missing.append(short_id)
                 logger.trace("Short id {} was requested but is unknown.", short_id)
 
         return TransactionSearchResult(found, missing)
@@ -462,30 +471,33 @@ class TransactionService:
         self.set_transaction_contents_base(
             transaction_hash,
             transaction_cache_key,
-            transaction_contents,
             has_short_id,
             previous_size,
-            True
+            True,
+            transaction_contents,
+            None
         )
 
     def set_transaction_contents_base(
         self,
         transaction_hash: Sha256Hash,
         transaction_cache_key: TransactionCacheKeyType,
-        transaction_contents: Union[bytearray, memoryview],
         has_short_id: bool,
         previous_size: int,
-        call_set_contents: bool
-    ):
+        call_set_contents: bool,
+        transaction_contents: Optional[Union[bytearray, memoryview]] = None,
+        transaction_contents_length: Optional[int] = None
+    ) -> None:
         """
         Adds transaction contents to transaction service cache with lookup key by transaction hash
 
         :param transaction_hash: transaction hash
         :param transaction_cache_key: transaction cache key
-        :param transaction_contents: transaction contents bytes
         :param has_short_id: flag indicating if cache already has short id for given transaction
         :param previous_size: previous size of transaction contents if already exists
         :param call_set_contents: flag indicating if method should make a call to set content form Python code
+        :param transaction_contents: transaction contents bytes
+        :param transaction_contents_length: if the transaction contents bytes not available, just send the length
         """
         if not has_short_id:
             self.tx_hashes_without_short_id.add(transaction_hash)
@@ -496,14 +508,18 @@ class TransactionService:
 
         self.tx_hashes_without_content.remove(transaction_hash)
 
-        if call_set_contents:
-            self._tx_cache_key_to_contents[transaction_cache_key] = transaction_contents
-
-        self._total_tx_contents_size += len(transaction_contents) - previous_size
+        if transaction_contents is not None:
+            self._total_tx_contents_size += len(transaction_contents) - previous_size
+            self.node.log_txs_network_content(self.network_num, wrap_sha256(transaction_hash), transaction_contents)
+            if call_set_contents:
+                self._tx_cache_key_to_contents[transaction_cache_key] = transaction_contents
+        elif transaction_contents_length is not None:
+            self._total_tx_contents_size += transaction_contents_length - previous_size
+        else:
+            logger.debug("both transaction contents and transaction contents length are missing.")
 
         self._memory_limit_clean_up()
 
-        self.node.log_txs_network_content(self.network_num, wrap_sha256(transaction_hash), transaction_contents)
 
     def remove_transaction_by_tx_hash(
         self,
@@ -862,10 +878,15 @@ class TransactionService:
         transaction_hash: Sha256Hash,
         short_id: int,
         transaction_contents: Union[bytearray, memoryview],
-        is_compact: bool) -> TransactionFromBdnGatewayProcessingResult:
+        is_compact: bool
+    ) -> TransactionFromBdnGatewayProcessingResult:
 
-        if (not short_id and self.has_transaction_short_id(transaction_hash) and
-            self.has_transaction_contents(transaction_hash)) or self.removed_transaction(transaction_hash):
+        # don't check removed_contents for messages from BDN
+        if (
+            not short_id
+            and self.has_transaction_short_id(transaction_hash)
+            and self.has_transaction_contents(transaction_hash)
+        ):
             return TransactionFromBdnGatewayProcessingResult(ignore_seen=True)
 
         existing_short_ids = self.get_short_ids(transaction_hash)
