@@ -16,17 +16,15 @@ _gc_start: Optional[float] = None
 def gc_callback(phase: str, info: Dict[str, Any]):
     # pylint: disable=global-statement
     global _gc_start
+    gc_start = _gc_start
 
-    if phase == "start":
-        assert _gc_start is None
+    if phase == "start" and gc_start is None:
         _gc_start = time.time()
-    else:
-        # pyre-fixme[6]: Expected `float` for 1st param but got `Optional[float]`.
-        duration = time.time() - _gc_start
+    elif gc_start is not None:
+        duration = time.time() - gc_start
         _gc_start = None
 
         if node_stats_service.node is not None:
-            # pyre-fixme[6]: Expected `int` for 2nd param but got `float`.
             node_stats_service.log_gc_duration(info["generation"], duration)
         gen0, gen1, gen2 = gc.get_count()
         if duration >= constants.GC_DURATION_WARN_THRESHOLD:
@@ -42,3 +40,5 @@ def gc_callback(phase: str, info: Dict[str, Any]):
                     "sizes": {"generation0": gen0, "generation1": gen1, "generation2": gen2},
                 }
             )
+    else:
+        logger.debug("invalid state when attempting to track GC state skip")
