@@ -50,7 +50,6 @@ from bxgateway.connections.abstract_relay_connection import AbstractRelayConnect
 from bxgateway.connections.gateway_connection import GatewayConnection
 from bxcommon.rpc import rpc_constants
 from bxgateway.feed.feed_manager import FeedManager
-from bxgateway.feed.pending_transaction_feed import PendingTransactionFeed
 from bxgateway.feed.new_transaction_feed import NewTransactionFeed
 from bxgateway.gateway_opts import GatewayOpts
 from bxgateway.rpc.https.gateway_http_rpc_server import GatewayHttpRpcServer
@@ -121,19 +120,19 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         opts: GatewayOpts,
         node_ssl_service: NodeSSLService,
         tracked_block_cleanup_interval_s=constants.CANCEL_ALARMS
-    ):
+    ) -> None:
         super(AbstractGatewayNode, self).__init__(
             opts, node_ssl_service
         )
         self.opts: GatewayOpts = opts
         if opts.split_relays:
-            opts.peer_transaction_relays = [
+            opts.peer_transaction_relays = {
                 OutboundPeerModel(peer_relay.ip, peer_relay.port + 1, node_type=NodeType.RELAY_TRANSACTION)
                 for peer_relay in opts.peer_relays
-            ]
-            opts.outbound_peers += opts.peer_transaction_relays
+            }
+            opts.outbound_peers.update(opts.peer_transaction_relays)
         else:
-            opts.peer_transaction_relays = []
+            opts.peer_transaction_relays = set()
 
         if opts.account_model:
             self.account_model = opts.account_model
@@ -141,7 +140,6 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             self.account_model = None
 
         self.quota_level = 0
-        self.last_quota_level_notification_time = 0.0
         self.peer_gateways = set(opts.peer_gateways)
         self.peer_relays = set(opts.peer_relays)
         self.peer_transaction_relays = set(opts.peer_transaction_relays)
@@ -234,10 +232,10 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             self.default_tx_quota_type = QuotaType.FREE_DAILY_QUOTA
 
         self.feed_manager = FeedManager()
-        self._rpc_server = GatewayHttpRpcServer(self)
+        self._rpc_server = self.build_rpc_server()
         self._ws_server = self.build_ws_server()
         self._ipc_server = IpcServer(opts.ipc_file, self.feed_manager, self)
-        self.init_live_feeds()
+        self.init_authorized_live_feeds()
 
         self.tracked_block_cleanup_interval_s = tracked_block_cleanup_interval_s
         if self.tracked_block_cleanup_interval_s > 0:
@@ -250,7 +248,21 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             ("quota",)
         )
         self.quota_gauge.labels("tx").set_function(
-            functools.partial(int, self.quota_level)
+            functools.partial(lambda: int(self.quota_level))
+        )
+        self.additional_servers = Gauge(
+            "additional_servers",
+            "Status of additional servers",
+            ("servers",)
+        )
+        self.additional_servers.labels("ws_server").set_function(
+            functools.partial(self._ws_server.status)
+        )
+        self.additional_servers.labels("ipc_server").set_function(
+            functools.partial(self._ipc_server.status)
+        )
+        self.additional_servers.labels("rpc_server").set_function(
+            functools.partial(self._rpc_server.status)
         )
 
         status_log.initialize(
@@ -292,23 +304,26 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
     def build_block_cleanup_service(self) -> AbstractBlockCleanupService:
         pass
 
+    def build_rpc_server(self) -> GatewayHttpRpcServer:
+        return GatewayHttpRpcServer(self)
+
     def build_ws_server(self) -> WsServer:
         return WsServer(self.opts.ws_host, self.opts.ws_port, self.feed_manager, self)
 
     def get_broadcast_service(self) -> BroadcastService:
         return GatewayBroadcastService(self.connection_pool)
 
-    def init_transaction_stat_logging(self):
+    def init_transaction_stat_logging(self) -> None:
         gateway_transaction_stats_service.set_node(self)
         self.alarm_queue.register_alarm(gateway_transaction_stats_service.interval,
                                         gateway_transaction_stats_service.flush_info)
 
-    def init_bdn_performance_stats_logging(self):
+    def init_bdn_performance_stats_logging(self) -> None:
         gateway_bdn_performance_stats_service.set_node(self)
         self.alarm_queue.register_alarm(gateway_bdn_performance_stats_service.interval,
                                         self.send_bdn_performance_stats)
 
-    def init_transaction_feed_stat_logging(self):
+    def init_transaction_feed_stat_logging(self) -> None:
         transaction_feed_stats_service.set_node(self)
         if self.opts.ws:
             self.alarm_queue.register_alarm(
@@ -316,32 +331,36 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
                 transaction_feed_stats_service.flush_info
             )
 
-    def init_live_feeds(self) -> None:
+    def init_authorized_live_feeds(self) -> None:
         account_model = self.account_model
-        if self.opts.ws and account_model and account_model.new_transaction_streaming.is_service_valid():
-            self.feed_manager.register_feed(NewTransactionFeed())
-            self.feed_manager.register_feed(PendingTransactionFeed(self.alarm_queue))
+        if (
+            self.opts.ws
+            and account_model
+            and account_model.new_transaction_streaming.is_service_valid()
+        ):
+            self.init_live_feeds()
         elif self.opts.ws:
             logger.warning(log_messages.TRANSACTION_FEED_NOT_ALLOWED)
 
+    def init_live_feeds(self) -> None:
+        self.feed_manager.register_feed(NewTransactionFeed())
+
     def send_bdn_performance_stats(self) -> int:
-        relay_connections = self.connection_pool.get_by_connection_type(ConnectionType.RELAY_BLOCK)
-        if not relay_connections:
+        relay_connection = next(iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_BLOCK])), None)
+        if not relay_connection:
             gateway_bdn_performance_stats_service.create_interval_data_object()
             return gateway_bdn_performance_stats_service.interval
 
-        relay_connection = cast(AbstractRelayConnection, next(iter(relay_connections)))
         gateway_bdn_performance_stats_service.close_interval_data()
-        # pyre-ignore
         relay_connection.send_bdn_performance_stats(gateway_bdn_performance_stats_service.interval_data)
         gateway_bdn_performance_stats_service.create_interval_data_object()
         return gateway_bdn_performance_stats_service.interval
 
-    def init_node_config_update(self):
+    def init_node_config_update(self) -> None:
         self.update_node_config()
         self.alarm_queue.register_alarm(constants.ALARM_QUEUE_INIT_EVENT, self.update_node_config)
 
-    def update_node_config(self):
+    def update_node_config(self) -> int:
         configuration_utils.update_node_config(self)
         return self.opts.config_update_interval
 
@@ -372,7 +391,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
 
         return self._tx_service
 
-    def on_fully_updated_tx_service(self):
+    def on_fully_updated_tx_service(self) -> None:
         super().on_fully_updated_tx_service()
         self.requester.send_threaded_request(sdn_http_service.submit_tx_synced_event,
                                              self.opts.node_id)
@@ -452,7 +471,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             except Exception as e:
                 logger.error(log_messages.IPC_INITIALIZATION_FAIL, e, exc_info=True)
 
-    async def close(self):
+    async def close(self) -> None:
         try:
             await asyncio.wait_for(self._rpc_server.stop(), rpc_constants.RPC_SERVER_STOP_TIMEOUT_S)
         except (Exception, CancelledError) as e:
@@ -564,10 +583,10 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
                          "Tried: {}:{}, from_me={}. Ignoring.", ip, port, from_me)
             return None
 
-    def is_local_blockchain_address(self, ip, port):
+    def is_local_blockchain_address(self, ip, port) -> bool:
         return ip == self.opts.blockchain_ip and port == self.opts.blockchain_port
 
-    def send_msg_to_node(self, msg: AbstractMessage):
+    def send_msg_to_node(self, msg: AbstractMessage) -> None:
         """
         Sends a message to the blockchain node this is connected to.
         """
@@ -578,7 +597,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             logger.trace("Adding message to local node's message queue: {}", msg)
             self.node_msg_queue.append(msg)
 
-    def send_msg_to_remote_node(self, msg: AbstractMessage):
+    def send_msg_to_remote_node(self, msg: AbstractMessage) -> None:
         """
         Sends a message to remote connected blockchain node.
         """
@@ -596,7 +615,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
                 or (connection_type == ConnectionType.REMOTE_BLOCKCHAIN_NODE and
                     self.num_retries_by_ip[(ip, port)] < gateway_constants.REMOTE_BLOCKCHAIN_MAX_CONNECT_RETRIES))
 
-    def on_blockchain_connection_ready(self, connection: AbstractGatewayBlockchainConnection):
+    def on_blockchain_connection_ready(self, connection: AbstractGatewayBlockchainConnection) -> None:
         for msg in self.node_msg_queue.pop_items():
             connection.enqueue_msg(msg)
 
@@ -610,7 +629,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             connection.peer_port
         )
 
-    def on_blockchain_connection_destroyed(self, connection: AbstractGatewayBlockchainConnection):
+    def on_blockchain_connection_destroyed(self, connection: AbstractGatewayBlockchainConnection) -> None:
         self.requester.send_threaded_request(sdn_http_service.submit_peer_connection_event,
                                              NodeEventType.BLOCKCHAIN_NODE_CONN_ERR,
                                              self.opts.node_id,
@@ -620,7 +639,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         self.node_conn = None
         self.node_msg_queue.pop_items()
 
-    def log_refused_connection(self, peer_info: ConnectionPeerInfo, error: str):
+    def log_refused_connection(self, peer_info: ConnectionPeerInfo, error: str) -> None:
         if peer_info.connection_type == ConnectionType.BLOCKCHAIN_NODE:
             logger.info("Failed to connect to: {}, {}. Verify that provided ip address ({}) and port ({}) "
                         "are correct. Verify that firewall port is open.", peer_info, error,
@@ -636,7 +655,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         else:
             super(AbstractGatewayNode, self).log_refused_connection(peer_info, error)
 
-    def on_remote_blockchain_connection_ready(self, connection: AbstractGatewayBlockchainConnection):
+    def on_remote_blockchain_connection_ready(self, connection: AbstractGatewayBlockchainConnection) -> None:
         for msg in self.remote_node_msg_queue.pop_items():
             connection.enqueue_msg(msg)
         self.remote_node_conn = connection
@@ -648,7 +667,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             connection.peer_port
         )
 
-    def on_remote_blockchain_connection_destroyed(self, connection: AbstractGatewayBlockchainConnection):
+    def on_remote_blockchain_connection_destroyed(self, connection: AbstractGatewayBlockchainConnection) -> None:
         self.requester.send_threaded_request(sdn_http_service.submit_peer_connection_event,
                                              NodeEventType.REMOTE_BLOCKCHAIN_CONN_ERR,
                                              self.opts.node_id,
@@ -657,7 +676,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         self.remote_node_conn = None
         self.remote_node_msg_queue.pop_items()
 
-    def on_relay_connection_ready(self):
+    def on_relay_connection_ready(self) -> None:
         self.cancel_relay_liveliness_check()
 
     def on_failed_connection_retry(self, ip: str, port: int, connection_type: ConnectionType) -> None:
@@ -695,7 +714,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         # Reset number of retries in case if SDN instructs to connect to the same node again
         self.num_retries_by_ip[(ip, port)] = 0
 
-    def on_updated_remote_blockchain_peer(self, outbound_peer):
+    def on_updated_remote_blockchain_peer(self, outbound_peer) -> None:
         self.remote_blockchain_ip = outbound_peer.ip
         self.remote_blockchain_port = outbound_peer.port
         self.enqueue_connection(outbound_peer.ip, outbound_peer.port, ConnectionType.REMOTE_BLOCKCHAIN_NODE)
@@ -703,7 +722,8 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
     def on_block_seen_by_blockchain_node(
         self,
         block_hash: Sha256Hash,
-        block_message: Optional[AbstractBlockMessage] = None
+        block_message: Optional[AbstractBlockMessage] = None,
+        block_number: Optional[int] = None
     ):
         self.blocks_seen.add(block_hash)
         recovery_canceled = self.block_recovery_service.cancel_recovery_for_block(block_hash)
@@ -713,7 +733,8 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
                                                       network_num=self.network_num)
         self.block_queuing_service.mark_block_seen_by_blockchain_node(
             block_hash,
-            block_message
+            block_message,
+            block_number
         )
 
         self.log_blocks_network_content(self.network_num, block_message)
@@ -725,31 +746,34 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         self,
         block_hash: Sha256Hash,
         short_ids: Iterable[int],
-        unknown_tx_hashes: Iterable[Sha256Hash]):
+        unknown_tx_hashes: Iterable[Sha256Hash]
+    ):
         """post cleanup tasks for blocks, override method to implement"""
         pass
 
-    def schedule_blockchain_liveliness_check(self, time_from_now_s: int):
+    def schedule_blockchain_liveliness_check(self, time_from_now_s: int) -> None:
         if not self._blockchain_liveliness_alarm and self.opts.require_blockchain_connection:
             self._blockchain_liveliness_alarm = self.alarm_queue.register_alarm(time_from_now_s,
                                                                                 self.check_blockchain_liveliness)
 
-    def schedule_relay_liveliness_check(self, time_from_now_s: int):
+    def schedule_relay_liveliness_check(self, time_from_now_s: int) -> None:
         if not self._relay_liveliness_alarm:
             self._relay_liveliness_alarm = self.alarm_queue.register_alarm(time_from_now_s,
                                                                            self.check_relay_liveliness)
 
-    def cancel_blockchain_liveliness_check(self):
-        if self._blockchain_liveliness_alarm:
-            self.alarm_queue.unregister_alarm(self._blockchain_liveliness_alarm)
+    def cancel_blockchain_liveliness_check(self) -> None:
+        blockchain_liveliness_alarm = self._blockchain_liveliness_alarm
+        if blockchain_liveliness_alarm:
+            self.alarm_queue.unregister_alarm(blockchain_liveliness_alarm)
             self._blockchain_liveliness_alarm = None
 
-    def cancel_relay_liveliness_check(self):
-        if self._relay_liveliness_alarm:
-            self.alarm_queue.unregister_alarm(self._relay_liveliness_alarm)
+    def cancel_relay_liveliness_check(self) -> None:
+        relay_liveliness_alarm = self._relay_liveliness_alarm
+        if relay_liveliness_alarm:
+            self.alarm_queue.unregister_alarm(relay_liveliness_alarm)
             self._relay_liveliness_alarm = None
 
-    def check_blockchain_liveliness(self):
+    def check_blockchain_liveliness(self) -> None:
         """
         Checks that the gateway has functional connections to the blockchain node.
 
@@ -759,8 +783,8 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             self.should_force_exit = True
             logger.error(log_messages.NO_ACTIVE_BLOCKCHAIN_CONNECTION)
 
-    def check_relay_liveliness(self):
-        if not self.connection_pool.get_by_connection_type(ConnectionType.RELAY_ALL):
+    def check_relay_liveliness(self) -> None:
+        if not list(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_ALL])):
             self.should_force_exit = True
             logger.error(log_messages.NO_ACTIVE_BDN_CONNECTIONS)
 
@@ -833,7 +857,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             ):
                 self.peer_gateways.add(gateway_peer)
 
-    def _remove_gateway_peer(self, ip, port):
+    def _remove_gateway_peer(self, ip, port) -> None:
         gateway_to_remove = None
         for peer_gateway in self.peer_gateways:
             if ip == peer_gateway.ip and port == peer_gateway.port:
@@ -847,7 +871,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
                 self.alarm_queue.register_alarm(constants.SDN_CONTACT_RETRY_SECONDS,
                                                 self._send_request_for_gateway_peers)
 
-    def _remove_relay_peer(self, ip: str, port: int):
+    def _remove_relay_peer(self, ip: str, port: int) -> None:
         """
         Clean up relay peer on connection failure. (after giving up retry)
         Destroys matching transaction relay if split relays enabled.
@@ -879,7 +903,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             )
             self._schedule_fetch_relays_from_sdn()
 
-    def _remove_relay_transaction_peer(self, ip: str, port: int, remove_block_relay: bool = True):
+    def _remove_relay_transaction_peer(self, ip: str, port: int, remove_block_relay: bool = True) -> None:
         """
         Clean up relay transactions peer on connection failure. (after giving up retry)
         Destroys matching block relay.
@@ -913,45 +937,55 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             f"{self.opts.blockchain_networks}"
         )
 
-    def sync_tx_services(self):
+    def sync_tx_services(self) -> int:
         logger.info("Starting to sync transaction state with BDN.")
         super(AbstractGatewayNode, self).sync_tx_services()
         if self.opts.sync_tx_service:
             retry = True
             if self.opts.split_relays:
-                relay_tx_connections = self.connection_pool.get_by_connection_type(ConnectionType.RELAY_TRANSACTION)
-                relay_block_connections = self.connection_pool.get_by_connection_type(ConnectionType.RELAY_BLOCK)
+                relay_tx_connection = next(
+                    iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_TRANSACTION])), None
+                )
+                relay_block_connection = next(
+                    iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_BLOCK])), None
+                )
 
-                if relay_tx_connections and relay_block_connections:
-                    relay_tx_connection = next(iter(relay_tx_connections))
-                    relay_block_connection = next(iter(relay_block_connections))
-
-                    if relay_tx_connection.is_active() and relay_block_connection.is_active():
-                        relay_tx_connection.send_tx_service_sync_req(self.network_num)
-                        relay_block_connection.send_tx_service_sync_req(self.network_num)
-                        retry = False
+                if relay_tx_connection and relay_block_connection and \
+                    relay_tx_connection.is_active() and relay_block_connection.is_active():
+                    relay_tx_connection.send_tx_service_sync_req(self.network_num)
+                    relay_block_connection.send_tx_service_sync_req(self.network_num)
+                    retry = False
             else:
-                relay_connections = self.connection_pool.get_by_connection_type(ConnectionType.RELAY_ALL)
-                if relay_connections:
-                    relay_connection = next(iter(relay_connections))
-                    if relay_connection.is_active():
-                        relay_connection.send_tx_service_sync_req(self.network_num)
-                        retry = False
+                relay_connection = next(
+                    iter(self.connection_pool.get_by_connection_types([ConnectionType.RELAY_ALL])), None
+                )
+                if relay_connection and relay_connection.is_active():
+                    relay_connection.send_tx_service_sync_req(self.network_num)
+                    retry = False
 
             if retry:
                 logger.info("Relay connection is not ready to sync transaction state with BDN. Scheduling retry.")
                 return constants.TX_SERVICE_SYNC_PROGRESS_S
         else:
             self.on_fully_updated_tx_service()
+        return constants.CANCEL_ALARMS
 
-    def _transaction_sync_timeout(self):
+    def _get_next_retry_timeout(self, ip: str, port: int) -> int:
+        base_timeout = super(AbstractGatewayNode, self)._get_next_retry_timeout(ip, port)
+
+        if self.is_local_blockchain_address(ip, port):
+            return base_timeout + gateway_constants.ADDITIONAL_BLOCKCHAIN_RECONNECT_TIMEOUT_S
+
+        return base_timeout
+
+    def _transaction_sync_timeout(self) -> int:
         if not self.opts.has_fully_updated_tx_service:
             logger.warning(log_messages.TX_SYNC_TIMEOUT)
             self.alarm_queue.unregister_alarm(self._check_sync_relay_connections_alarm_id)
             self.on_fully_updated_tx_service()
-            return constants.CANCEL_ALARMS
+        return constants.CANCEL_ALARMS
 
-    def _check_sync_relay_connections(self):
+    def _check_sync_relay_connections(self) -> None:
         if (
             self.network_num in self.last_sync_message_received_by_network
             and time.time() - self.last_sync_message_received_by_network[self.network_num]
@@ -1039,7 +1073,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
         best_relay_peers = ping_potential_relays_future.result()
         self._register_potential_relay_peers(best_relay_peers)
 
-    def _register_potential_relay_peers(self, best_relay_peers: List[OutboundPeerModel]):
+    def _register_potential_relay_peers(self, best_relay_peers: List[OutboundPeerModel]) -> None:
         best_relay_set = set(best_relay_peers)
 
         to_disconnect = self.peer_relays - best_relay_set
@@ -1076,7 +1110,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             gateway_constants.RELAY_CONNECTION_REEVALUATION_INTERVAL_S
         )
 
-    def _tracked_block_cleanup(self):
+    def _tracked_block_cleanup(self) -> float:
         tx_service = self.get_tx_service()
         block_queuing_service = self.block_queuing_service
         if self.block_queuing_service is not None:
@@ -1094,7 +1128,7 @@ class AbstractGatewayNode(AbstractNode, metaclass=ABCMeta):
             logger.warning(log_messages.TRACKED_BLOCK_CLEANUP_ERROR, "block queuing service is not available")
         return self.tracked_block_cleanup_interval_s
 
-    def on_new_subscriber(self) -> None:
+    def on_new_subscriber_request(self) -> None:
         pass
 
     def _schedule_fetch_relays_from_sdn(
