@@ -291,6 +291,19 @@ def get_argument_parser() -> argparse.ArgumentParser:
         default=True,
         type=convert.str_to_bool,
     )
+    arg_parser.add_argument(
+        "--request-recovery",
+        help="If true, gateway will send transaction recovery request to relay when unable to decompress a block",
+        default=False,
+        type=convert.str_to_bool,
+    )
+    arg_parser.add_argument(
+        "--enable-block-compression",
+        help="If set, overrides value from the SDN, and might be changed if SDN sent an update",
+        type=convert.str_to_bool,
+        nargs='?',
+    )
+
     return arg_parser
 
 
